@@ -21,7 +21,7 @@
 
 #ifndef lint
 static const char rcsid[] =
-    "@(#) $Header: /tcpdump/master/tcpdump/print-domain.c,v 1.64 2001/01/02 23:24:51 guy Exp $ (LBL)";
+    "@(#) $Header: /tcpdump/master/tcpdump/print-domain.c,v 1.78 2001/10/19 09:00:48 guy Exp $ (LBL)";
 #endif
 
 #ifdef HAVE_CONFIG_H
@@ -33,12 +33,6 @@ static const char rcsid[] =
 
 #include <netinet/in.h>
 
-#ifdef NOERROR
-#undef NOERROR					/* Solaris sucks */
-#endif
-#ifdef NOERROR
-#undef T_UNSPEC					/* SINIX does too */
-#endif
 #include "nameser.h"
 
 #include <stdio.h>
@@ -48,102 +42,16 @@ static const char rcsid[] =
 #include "addrtoname.h"
 #include "extract.h"                    /* must come after interface.h */
 
-/* Compatibility */
-#ifndef T_TXT
-#define T_TXT		16		/* text strings */
-#endif
-#ifndef T_RP
-#define T_RP		17		/* responsible person */
-#endif
-#ifndef T_AFSDB
-#define T_AFSDB		18		/* AFS cell database */
-#endif
-#ifndef T_X25
-#define T_X25		19		/* X_25 calling address */
-#endif
-#ifndef T_ISDN
-#define T_ISDN		20		/* ISDN calling address */
-#endif
-#ifndef T_RT
-#define T_RT		21		/* router */
-#endif
-#ifndef T_NSAP
-#define T_NSAP		22		/* NSAP address */
-#endif
-#ifndef T_NSAP_PTR
-#define T_NSAP_PTR	23		/* reverse NSAP lookup (deprecated) */
-#endif
-#ifndef T_SIG
-#define T_SIG		24		/* security signature */
-#endif
-#ifndef T_KEY
-#define T_KEY		25		/* security key */
-#endif
-#ifndef T_PX
-#define T_PX		26		/* X.400 mail mapping */
-#endif
-#ifndef T_GPOS
-#define T_GPOS		27		/* geographical position (withdrawn) */
-#endif
-#ifndef T_AAAA
-#define T_AAAA		28		/* IP6 Address */
-#endif
-#ifndef T_LOC
-#define T_LOC		29		/* Location Information */
-#endif
-#ifndef T_NXT
-#define T_NXT		30		/* Next Valid Name in Zone */
-#endif
-#ifndef T_EID
-#define T_EID		31		/* Endpoint identifier */
-#endif
-#ifndef T_NIMLOC
-#define T_NIMLOC	32		/* Nimrod locator */
-#endif
-#ifndef T_SRV
-#define T_SRV		33		/* Server selection */
-#endif
-#ifndef T_ATMA
-#define T_ATMA		34		/* ATM Address */
-#endif
-#ifndef T_NAPTR
-#define T_NAPTR		35		/* Naming Authority PoinTeR */
-#endif
-#ifndef T_A6
-#define T_A6		38		/* IP6 address */
-#endif
-#ifndef T_DNAME
-#define T_DNAME		39		/* non-terminal redirection */
-#endif
-
-#ifndef T_OPT
-#define T_OPT		41		/* EDNS0 option (meta-RR) */
-#endif
-
-#ifndef T_UNSPEC
-#define T_UNSPEC	103		/* Unspecified format (binary data) */
-#endif
-#ifndef T_UNSPECA
-#define T_UNSPECA	104		/* "unspecified ascii". Ugly MIT hack */
-#endif
-
-#ifndef C_CHAOS
-#define C_CHAOS		3		/* for chaos net (MIT) */
-#endif
-#ifndef C_HS
-#define C_HS		4		/* for Hesiod name server (MIT) (XXX) */
-#endif
-
-static char *ns_ops[] = {
-	"", " inv_q", " stat", " op3", " notify", " op5", " op6", " op7",
+static const char *ns_ops[] = {
+	"", " inv_q", " stat", " op3", " notify", " update", " op6", " op7",
 	" op8", " updataA", " updateD", " updateDA",
 	" updateM", " updateMA", " zoneInit", " zoneRef",
 };
 
-static char *ns_resp[] = {
+static const char *ns_resp[] = {
 	"", " FormErr", " ServFail", " NXDomain",
-	" NotImp", " Refused", " Resp6", " Resp7",
-	" Resp8", " Resp9", " Resp10", " Resp11",
+	" NotImp", " Refused", " YXDomain", " YXRRSet",
+	" NXRRSet", " NotAuth", " NotZone", " Resp11",
 	" Resp12", " Resp13", " Resp14", " NoChange",
 };
 
@@ -153,24 +61,26 @@ ns_nskip(register const u_char *cp, register const u_char *bp)
 {
 	register u_char i;
 
+	if (!TTEST2(*cp, 1))
+		return (NULL);
 	if (((i = *cp++) & INDIR_MASK) == INDIR_MASK)
 		return (cp + 1);
-	if (cp >= snapend)
-		return(NULL);
-	while (i && cp < snapend) {
+	while (i) {
 		if ((i & INDIR_MASK) == EDNS0_MASK) {
 			int bitlen, bytelen;
 
 			if ((i & ~INDIR_MASK) != EDNS0_ELT_BITLABEL)
 				return(NULL); /* unknown ELT */
+			if (!TTEST2(*cp, 1))
+				return (NULL);
 			if ((bitlen = *cp++) == 0)
 				bitlen = 256;
 			bytelen = (bitlen + 7) / 8;
 			cp += bytelen;
 		} else
 			cp += i;
-		if (cp >= snapend)
-			return(NULL);
+		if (!TTEST2(*cp, 1))
+			return (NULL);
 		i = *cp++;
 	}
 	return (cp);
@@ -185,7 +95,7 @@ blabel_print(const u_char *cp)
 	const u_char *bitp, *lim;
 	char tc;
 
-	if (cp >= snapend)
+	if (!TTEST2(*cp, 1))
 		return(NULL);
 	if ((bitlen = *cp) == 0)
 		bitlen = 256;
@@ -218,7 +128,7 @@ labellen(const u_char *cp)
 {
 	register u_int i;
 
-	if (cp >= snapend)
+	if (!TTEST2(*cp, 1))
 		return(-1);
 	i = *cp;
 	if ((i & INDIR_MASK) == EDNS0_MASK) {
@@ -226,7 +136,7 @@ labellen(const u_char *cp)
 
 		if ((elt = (i & ~INDIR_MASK)) != EDNS0_ELT_BITLABEL)
 			return(-1);
-		if (cp + 1 >= snapend)
+		if (!TTEST2(*(cp + 1), 1))
 			return(-1);
 		if ((bitlen = *(cp + 1)) == 0)
 			bitlen = 256;
@@ -247,7 +157,7 @@ ns_nprint(register const u_char *cp, register const u_char *bp)
 
 	if ((l = labellen(cp)) < 0)
 		return(NULL);
-	if (cp >= snapend)
+	if (!TTEST2(*cp, 1))
 		return(NULL);
 	chars_processed = 1;
 	if (((i = *cp++) & INDIR_MASK) != INDIR_MASK) {
@@ -262,11 +172,13 @@ ns_nprint(register const u_char *cp, register const u_char *bp)
 					rp = cp + 1;
 					compress = 1;
 				}
-				cp = bp + (((i << 8) | *cp) & 0x3fff);
-				if (cp >= snapend)
+				if (!TTEST2(*cp, 1))
 					return(NULL);
+				cp = bp + (((i << 8) | *cp) & 0x3fff);
 				if ((l = labellen(cp)) < 0)
 					return(NULL);
+				if (!TTEST2(*cp, 1))
+					return(NULL);
 				i = *cp++;
 				chars_processed++;
 
@@ -286,7 +198,8 @@ ns_nprint(register const u_char *cp, register const u_char *bp)
 				elt = (i & ~INDIR_MASK);
 				switch(elt) {
 				case EDNS0_ELT_BITLABEL:
-					blabel_print(cp);
+					if (blabel_print(cp) == NULL)
+						return (NULL);
 					break;
 				default:
 					/* unknown ELT */
@@ -295,13 +208,15 @@ ns_nprint(register const u_char *cp, register const u_char *bp)
 				}
 			} else {
 				if (fn_printn(cp, l, snapend))
-					break;
+					return(NULL);
 			}
 
 			cp += l;
 			chars_processed += l;
 			putchar('.');
-			if (cp >= snapend || (l = labellen(cp)) < 0)
+			if ((l = labellen(cp)) < 0)
+				return(NULL);
+			if (!TTEST2(*cp, 1))
 				return(NULL);
 			i = *cp++;
 			chars_processed++;
@@ -319,14 +234,15 @@ ns_cprint(register const u_char *cp, register const u_char *bp)
 {
 	register u_int i;
 
-	if (cp >= snapend)
-		return NULL;
+	if (!TTEST2(*cp, 1))
+		return (NULL);
 	i = *cp++;
-	(void)fn_printn(cp, i, snapend);
+	if (fn_printn(cp, i, snapend))
+		return (NULL);
 	return (cp + i);
 }
 
-static struct tok type2str[] = {
+struct tok ns_type2str[] = {
 	{ T_A,		"A" },
 	{ T_NS,		"NS" },
 	{ T_MD,		"MD" },
@@ -355,21 +271,24 @@ static struct tok type2str[] = {
 	{ T_PX,		"PX" },
 	{ T_GPOS,	"GPOS" },
 	{ T_AAAA,	"AAAA" },
-	{ T_LOC,	"LOC " },
-	{ T_NXT,	"NXT " },
-	{ T_EID,	"EID " },
-	{ T_NIMLOC,	"NIMLOC " },
-	{ T_SRV,	"SRV " },
-	{ T_ATMA,	"ATMA " },
-	{ T_NAPTR,	"NAPTR " },
-	{ T_A6,		"A6 " },
-	{ T_DNAME,	"DNAME " },
-	{ T_OPT,	"OPT " },
+	{ T_LOC,	"LOC" },
+	{ T_NXT,	"NXT" },
+	{ T_EID,	"EID" },
+	{ T_NIMLOC,	"NIMLOC" },
+	{ T_SRV,	"SRV" },
+	{ T_ATMA,	"ATMA" },
+	{ T_NAPTR,	"NAPTR" },
+	{ T_A6,		"A6" },
+	{ T_DNAME,	"DNAME" },
+	{ T_OPT,	"OPT" },
 	{ T_UINFO,	"UINFO" },
 	{ T_UID,	"UID" },
 	{ T_GID,	"GID" },
 	{ T_UNSPEC,	"UNSPEC" },
 	{ T_UNSPECA,	"UNSPECA" },
+	{ T_TKEY,	"TKEY" },
+	{ T_TSIG,	"TSIG" },
+	{ T_IXFR,	"IXFR" },
 	{ T_AXFR,	"AXFR" },
 	{ T_MAILB,	"MAILB" },
 	{ T_MAILA,	"MAILA" },
@@ -377,9 +296,9 @@ static struct tok type2str[] = {
 	{ 0,		NULL }
 };
 
-static struct tok class2str[] = {
+struct tok ns_class2str[] = {
 	{ C_IN,		"IN" },		/* Not used */
-	{ C_CHAOS,	"CHAOS)" },
+	{ C_CHAOS,	"CHAOS" },
 	{ C_HS,		"HS" },
 	{ C_ANY,	"ANY" },
 	{ 0,		NULL }
@@ -394,17 +313,17 @@ ns_qprint(register const u_char *cp, register const u_char *bp)
 
 	cp = ns_nskip(cp, bp);
 
-	if (cp + 4 > snapend || cp == NULL)
+	if (cp == NULL || !TTEST2(*cp, 4))
 		return(NULL);
 
 	/* print the qtype and qclass (if it's not IN) */
 	i = *cp++ << 8;
 	i |= *cp++;
-	printf(" %s", tok2str(type2str, "Type%d", i));
+	printf(" %s", tok2str(ns_type2str, "Type%d", i));
 	i = *cp++ << 8;
 	i |= *cp++;
 	if (i != C_IN)
-		printf(" %s", tok2str(class2str, "(Class %d)", i));
+		printf(" %s", tok2str(ns_class2str, "(Class %d)", i));
 
 	fputs("? ", stdout);
 	cp = ns_nprint(np, bp);
@@ -426,7 +345,7 @@ ns_rprint(register const u_char *cp, register const u_char *bp)
 	} else
 		cp = ns_nskip(cp, bp);
 
-	if (cp + 10 > snapend || cp == NULL)
+	if (cp == NULL || !TTEST2(*cp, 10))
 		return (snapend);
 
 	/* print the type/qtype and class (if it's not IN) */
@@ -435,7 +354,7 @@ ns_rprint(register const u_char *cp, register const u_char *bp)
 	class = *cp++ << 8;
 	class |= *cp++;
 	if (class != C_IN && typ != T_OPT)
-		printf(" %s", tok2str(class2str, "(Class %d)", class));
+		printf(" %s", tok2str(ns_class2str, "(Class %d)", class));
 
 	/* ignore ttl */
 	cp += 4;
@@ -445,13 +364,13 @@ ns_rprint(register const u_char *cp, register const u_char *bp)
 
 	rp = cp + len;
 
-	printf(" %s", tok2str(type2str, "Type%d", typ));
+	printf(" %s", tok2str(ns_type2str, "Type%d", typ));
 	if (rp > snapend)
 		return(NULL);
 
 	switch (typ) {
 	case T_A:
-		if (cp + sizeof(struct in_addr) > snapend)
+		if (!TTEST2(*cp, sizeof(struct in_addr)))
 			return(NULL);
 		printf(" %s", ipaddr_string(cp));
 		break;
@@ -476,7 +395,7 @@ ns_rprint(register const u_char *cp, register const u_char *bp)
 		putchar(' ');
 		if ((cp = ns_nprint(cp, bp)) == NULL)
 			return(NULL);
-		if (cp + 5 * 4 > snapend)
+		if (!TTEST2(*cp, 5 * 4))
 			return(NULL);
 		printf(" %u", EXTRACT_32BITS(cp));
 		cp += 4;
@@ -491,7 +410,7 @@ ns_rprint(register const u_char *cp, register const u_char *bp)
 		break;
 	case T_MX:
 		putchar(' ');
-		if (cp + 2 > snapend)
+		if (!TTEST2(*cp, 2))
 			return(NULL);
 		if (ns_nprint(cp + 2, bp) == NULL)
 			return(NULL);
@@ -505,7 +424,7 @@ ns_rprint(register const u_char *cp, register const u_char *bp)
 
 #ifdef INET6
 	case T_AAAA:
-		if (cp + sizeof(struct in6_addr) > snapend)
+		if (!TTEST2(*cp, sizeof(struct in6_addr)))
 			return(NULL);
 		printf(" %s", ip6addr_string(cp));
 		break;
@@ -515,12 +434,16 @@ ns_rprint(register const u_char *cp, register const u_char *bp)
 		struct in6_addr a;
 		int pbit, pbyte;
 
+		if (!TTEST2(*cp, 1))
+			return(NULL);
 		pbit = *cp;
 		pbyte = (pbit & ~7) / 8;
 		if (pbit > 128) {
 			printf(" %u(bad plen)", pbit);
 			break;
 		} else if (pbit < 128) {
+			if (!TTEST2(*(cp + 1), sizeof(a) - pbyte))
+				return(NULL);
 			memset(&a, 0, sizeof(a));
 			memcpy(&a.s6_addr[pbyte], cp + 1, sizeof(a) - pbyte);
 			printf(" %u %s", pbit, ip6addr_string(&a));
@@ -539,10 +462,43 @@ ns_rprint(register const u_char *cp, register const u_char *bp)
 		break;
 
 	case T_UNSPECA:		/* One long string */
+		if (!TTEST2(*cp, len))
+			return(NULL);
+		if (fn_printn(cp, len, snapend))
+			return(NULL);
+		break;
+
+	case T_TSIG:
+	    {
 		if (cp + len > snapend)
 			return(NULL);
-		fn_printn(cp, len, snapend);
-		break;
+		if (!vflag)
+			break;
+		putchar(' ');
+		if ((cp = ns_nprint(cp, bp)) == NULL)
+			return(NULL);
+		cp += 6;
+		if (!TTEST2(*cp, 2))
+			return(NULL);
+		printf(" fudge=%u", EXTRACT_16BITS(cp));
+		cp += 2;
+		if (!TTEST2(*cp, 2))
+			return(NULL);
+		printf(" maclen=%u", EXTRACT_16BITS(cp));
+		cp += 2 + EXTRACT_16BITS(cp);
+		if (!TTEST2(*cp, 2))
+			return(NULL);
+		printf(" origid=%u", EXTRACT_16BITS(cp));
+		cp += 2;
+		if (!TTEST2(*cp, 2))
+			return(NULL);
+		printf(" error=%u", EXTRACT_16BITS(cp));
+		cp += 2;
+		if (!TTEST2(*cp, 2))
+			return(NULL);
+		printf(" otherlen=%u", EXTRACT_16BITS(cp));
+		cp += 2;
+	    }
 	}
 	return (rp);		/* XXX This isn't always right */
 }
@@ -552,9 +508,10 @@ ns_print(register const u_char *bp, u_int length)
 {
 	register const HEADER *np;
 	register int qdcount, ancount, nscount, arcount;
-	register const u_char *cp = NULL;
+	register const u_char *cp;
 
 	np = (const HEADER *)bp;
+	TCHECK(*np);
 	/* get the byte-order right */
 	qdcount = ntohs(np->qdcount);
 	ancount = ntohs(np->ancount);
@@ -575,49 +532,58 @@ ns_print(register const u_char *bp, u_int length)
 		if (qdcount != 1)
 			printf(" [%dq]", qdcount);
 		/* Print QUESTION section on -vv */
-		if (vflag > 1) {
-			fputs(" q:", stdout);
-			if ((cp = ns_qprint((const u_char *)(np + 1), bp))
-			    == NULL)
-				goto trunc;
-		} else {
-			if ((cp = ns_nskip((const u_char *)(np + 1), bp))
-			    == NULL)
-				goto trunc;
-			cp += 4;
+		cp = (const u_char *)(np + 1);
+		while (qdcount--) {
+			if (qdcount < ntohs(np->qdcount) - 1)
+				putchar(',');
+			if (vflag > 1) {
+				fputs(" q:", stdout);
+				if ((cp = ns_qprint(cp, bp)) == NULL)
+					goto trunc;
+			} else {
+				if ((cp = ns_nskip(cp, bp)) == NULL)
+					goto trunc;
+				cp += 4;	/* skip QTYPE and QCLASS */
+			}
 		}
 		printf(" %d/%d/%d", ancount, nscount, arcount);
 		if (ancount--) {
 			if ((cp = ns_rprint(cp, bp)) == NULL)
 				goto trunc;
-			while (ancount-- && cp < snapend) {
+			while (cp < snapend && ancount--) {
 				putchar(',');
 				if ((cp = ns_rprint(cp, bp)) == NULL)
 					goto trunc;
 			}
 		}
+		if (ancount > 0)
+			goto trunc;
 		/* Print NS and AR sections on -vv */
 		if (vflag > 1) {
-			if (nscount-- && cp < snapend) {
+			if (cp < snapend && nscount--) {
 				fputs(" ns:", stdout);
 				if ((cp = ns_rprint(cp, bp)) == NULL)
 					goto trunc;
-				while (nscount-- && cp < snapend) {
+				while (cp < snapend && nscount--) {
 					putchar(',');
 					if ((cp = ns_rprint(cp, bp)) == NULL)
 						goto trunc;
 				}
 			}
-			if (arcount-- && cp < snapend) {
+			if (nscount > 0)
+				goto trunc;
+			if (cp < snapend && arcount--) {
 				fputs(" ar:", stdout);
 				if ((cp = ns_rprint(cp, bp)) == NULL)
 					goto trunc;
-				while (arcount-- && cp < snapend) {
+				while (cp < snapend && arcount--) {
 					putchar(',');
 					if ((cp = ns_rprint(cp, bp)) == NULL)
 						goto trunc;
 				}
 			}
+			if (arcount > 0)
+				goto trunc;
 		}
 	}
 	else {
@@ -647,35 +613,35 @@ ns_print(register const u_char *bp, u_int length)
 		if (arcount)
 			printf(" [%dau]", arcount);
 
+		cp = (const u_char *)(np + 1);
 		if (qdcount--) {
-			cp = ns_qprint((const u_char *)(np + 1),
-				       (const u_char *)np);
+			cp = ns_qprint(cp, (const u_char *)np);
 			if (!cp)
 				goto trunc;
-			if ((cp = ns_rprint(cp, bp)) == NULL)
-				goto trunc;
-			while (qdcount-- && cp < snapend) {
+			while (cp < snapend && qdcount--) {
 				cp = ns_qprint((const u_char *)cp,
 					       (const u_char *)np);
 				if (!cp)
 					goto trunc;
-				if ((cp = ns_rprint(cp, bp)) == NULL)
-					goto trunc;
 			}
 		}
+		if (qdcount > 0)
+			goto trunc;
 
 		/* Print remaining sections on -vv */
 		if (vflag > 1) {
 			if (ancount--) {
 				if ((cp = ns_rprint(cp, bp)) == NULL)
 					goto trunc;
-				while (ancount-- && cp < snapend) {
+				while (cp < snapend && ancount--) {
 					putchar(',');
 					if ((cp = ns_rprint(cp, bp)) == NULL)
 						goto trunc;
 				}
 			}
-			if (nscount-- && cp < snapend) {
+			if (ancount > 0)
+				goto trunc;
+			if (cp < snapend && nscount--) {
 				fputs(" ns:", stdout);
 				if ((cp = ns_rprint(cp, bp)) == NULL)
 					goto trunc;
@@ -685,16 +651,20 @@ ns_print(register const u_char *bp, u_int length)
 						goto trunc;
 				}
 			}
-			if (arcount-- && cp < snapend) {
+			if (nscount > 0)
+				goto trunc;
+			if (cp < snapend && arcount--) {
 				fputs(" ar:", stdout);
 				if ((cp = ns_rprint(cp, bp)) == NULL)
 					goto trunc;
-				while (arcount-- && cp < snapend) {
+				while (cp < snapend && arcount--) {
 					putchar(',');
 					if ((cp = ns_rprint(cp, bp)) == NULL)
 						goto trunc;
 				}
 			}
+			if (arcount > 0)
+				goto trunc;
 		}
 	}
 	printf(" (%d)", length);
