@@ -21,7 +21,7 @@
 
 #ifndef lint
 static const char rcsid[] =
-    "@(#) $Header: /tcpdump/master/tcpdump/print-pim.c,v 1.29 2001/07/04 21:36:15 fenner Exp $ (LBL)";
+    "@(#) $Header: /tcpdump/master/tcpdump/print-pim.c,v 1.29.4.1 2002/05/07 18:30:19 fenner Exp $ (LBL)";
 #endif
 
 #ifdef HAVE_CONFIG_H
@@ -584,7 +584,20 @@ pimv2_print(register const u_char *bp, register u_int len)
 				(void)printf(")");
 				break;
 
+			case 18:	/* Old DR-Priority */
+				if (olen == 4)
+					(void)printf(" (OLD-DR-Priority: %d)", 
+							EXTRACT_32BITS(&bp[4]));
+				else
+					goto unknown;
+				break;
+
+
 			case 19:	/* DR-Priority */
+				if (olen == 0) {
+					(void)printf(" (OLD-bidir-capable)");
+					break;
+				}
 				(void)printf(" (DR-Priority: ");
 				if (olen != 4) {
 					(void)printf("!olen=%d!)", olen);
@@ -614,6 +627,7 @@ pimv2_print(register const u_char *bp, register u_int len)
 				break;
 
 			default:
+			unknown:
 				if (vflag)
 					(void)printf(" [Hello option %d]", otype);
 			}
