@@ -12,13 +12,15 @@
 
 #ifndef lint
 static const char rcsid[] =
-     "@(#) $Header: /tcpdump/master/tcpdump/print-smb.c,v 1.20 2002/01/17 04:38:29 guy Exp $";
+     "@(#) $Header: /tcpdump/master/tcpdump/print-smb.c,v 1.20.2.4 2002/07/11 07:47:01 guy Exp $";
 #endif
 
 #include <stdio.h>
 #include <string.h>
 #include <sys/types.h>
 
+#include <netinet/in.h>
+
 #include "interface.h"
 #include "extract.h"
 #include "smb.h"
@@ -173,7 +175,7 @@ print_trans2(const u_char *words, const u_char *dat, const u_char *buf, const u_
     static struct smbfnsint *fn = &trans2_fns[0];
     const u_char *data, *param;
     const u_char *w = words + 1;
-    const u_char *f1 = NULL, *f2 = NULL;
+    const char *f1 = NULL, *f2 = NULL;
     int pcnt, dcnt;
 
     TCHECK(words[0]);
@@ -224,8 +226,8 @@ print_trans2(const u_char *words, const u_char *dat, const u_char *buf, const u_
     if (fn->descript.fn)
 	(*fn->descript.fn)(param, data, pcnt, dcnt);
     else {
-	smb_fdata(param, f1 ? f1 : (u_char *)"Paramaters=\n", param + pcnt);
-	smb_fdata(data, f2 ? f2 : (u_char *)"Data=\n", data + dcnt);
+	smb_fdata(param, f1 ? f1 : "Parameters=\n", param + pcnt);
+	smb_fdata(data, f2 ? f2 : "Data=\n", data + dcnt);
     }
     return;
 trunc:
@@ -329,7 +331,7 @@ print_ipc(const u_char *param, int paramlen, const u_char *data, int datalen)
 static void
 print_trans(const u_char *words, const u_char *data1, const u_char *buf, const u_char *maxbuf)
 {
-    const u_char *f1, *f2, *f3, *f4;
+    const char *f1, *f2, *f3, *f4;
     const u_char *data, *param;
     const u_char *w = words + 1;
     int datalen, paramlen;
@@ -359,12 +361,12 @@ print_trans(const u_char *words, const u_char *data1, const u_char *buf, const u
     smb_fdata(words + 1, f1, SMBMIN(words + 1 + 2 * words[0], maxbuf));
     smb_fdata(data1 + 2, f2, maxbuf - (paramlen + datalen));
 
-    if (!strcmp(data1 + 2, "\\MAILSLOT\\BROWSE")) {
+    if (strcmp((const char *)(data1 + 2), "\\MAILSLOT\\BROWSE") == 0) {
 	print_browse(param, paramlen, data, datalen);
 	return;
     }
 
-    if (!strcmp(data1 + 2, "\\PIPE\\LANMAN")) {
+    if (strcmp((const char *)(data1 + 2), "\\PIPE\\LANMAN") == 0) {
 	print_ipc(param, paramlen, data, datalen);
 	return;
     }
@@ -383,7 +385,7 @@ trunc:
 static void
 print_negprot(const u_char *words, const u_char *data, const u_char *buf, const u_char *maxbuf)
 {
-    u_char *f1 = NULL, *f2 = NULL;
+    const char *f1 = NULL, *f2 = NULL;
 
     TCHECK(words[0]);
     if (request)
@@ -418,7 +420,7 @@ static void
 print_sesssetup(const u_char *words, const u_char *data, const u_char *buf, const u_char *maxbuf)
 {
     int wcnt;
-    u_char *f1 = NULL, *f2 = NULL;
+    const char *f1 = NULL, *f2 = NULL;
 
     TCHECK(words[0]);
     wcnt = words[0];
@@ -762,7 +764,7 @@ print_smb(const u_char *buf, const u_char *maxbuf)
     TCHECK(words[0]);
 
     for (;;) {
-	const u_char *f1, *f2;
+	const char *f1, *f2;
 	int wct;
 	int bcc;
 
@@ -857,9 +859,9 @@ nbt_tcp_print(const u_char *data, int length)
 	return;
 
     if (vflag > 1)
-	printf ("\n>>> ");
+	printf ("\n>>>");
 
-    printf("NBT Packet");
+    printf(" NBT Packet");
 
     if (vflag < 2)
 	return;
@@ -949,7 +951,7 @@ nbt_udp137_print(const u_char *data, int length)
     int name_trn_id, response, opcode, nm_flags, rcode;
     int qdcount, ancount, nscount, arcount;
     char *opcodestr;
-    const char *p;
+    const u_char *p;
     int total, i;
 
     TCHECK2(data[10], 2);
@@ -1078,14 +1080,14 @@ nbt_udp137_print(const u_char *data, int length)
 			p += 2;
 		    }
 		} else {
-		    print_data(p, min(rdlen, length - ((const u_char *)p - data)));
+		    print_data(p, min(rdlen, length - (p - data)));
 		    p += rdlen;
 		}
 	    }
 	}
     }
 
-    if ((u_char*)p < maxbuf)
+    if (p < maxbuf)
 	smb_fdata(p, "AdditionalData:\n", maxbuf);
 
 out:
